﻿using Gsiot.Server;
using SecretLabs.NETMF.Hardware.NetduinoPlus;

namespace LedControllerHTML
{
    public class Program
    {
        public static void Main()
        {
            var ledActuator = new DigitalActuator
            {
                OutputPin = Pins.ONBOARD_LED
            };


            var webServer = new HttpServer
            {
                RequestRouting =
            {
                {
                    "PUT /led/target",
                    new ManipulatedVariable
                    {
                        FromHttpRequest =
                            CSharpRepresentation.TryDeserializeBool,
                        ToActuator = ledActuator.HandlePut
                    }.HandleRequest
                },
                {
                    "GET /index.html",
                    HandleLedTargetHtml
                },
                {
                    "GET /*",Context => {Context.SetResponse("Erreur 404","text/plain");}
                }
            }
            };

            webServer.Run();
        }

        static void HandleLedTargetHtml(RequestHandlerContext context)
        {
            string requestUri = context.BuildRequestUri("/led/target");
            
            var script =
                @"<html>
                <head>
                  <script type=""text/javascript"">
                    var request;
                    try {
                      request = new XMLHttpRequest();
                    } catch (e) {
                      request = new ActiveXObject('Microsoft.XMLHTTP');
                    }
                    function put (content) {
                      request.open('PUT', '" + requestUri + @"');
                      request.setRequestHeader('Content-Type', 'text/plain');
                      request.send(content);
                    }
                  </script>
                </head>
                <body>
                  <p>
                    <input type=""button"" value=""Switch LED on""  
                      onclick=""put('true')""/>
                    <input type=""button"" value=""Switch LED off"" 
                      onclick=""put('false')""/>
                  </p>
                </body>
             </html>";

            context.SetResponse(script, "text/html");
        }
    }
}
