﻿//distributed under the License is distributed on an "AS IS" BASIS,
//WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//See the License for the specific language governing permissions and
//limitations under the License.

//Developed for the book
//  "Getting Started with the Internet of Things", by Cuno Pfister.
//  Copyright 2011 Cuno Pfister, Inc., 978-1-4493-9357-1.
//
// Version 4.3, for the .NET Micro Framework release 4.3.
//
// Adapté par Philippe Mariano 8/2014
//
using Microsoft.SPOT;
using System;
using System.Threading;
using System.IO;
using System.Net;
using System.Text;

namespace MFClassLibraryPut
{
    public static class PutClient
    {
        /// <summary>
        /// 
        /// </summary>
        /// <param name="baseUri"></param>
        /// <param name="sample"></param>
        public static void Send(string baseUri, string sample)
        {
            Debug.Print("time: " + DateTime.Now);
            Debug.Print("memory available: " + Debug.GC(true) + "\n");
            try
            {
                using (var request = CreateRequest(baseUri, sample))
                {
                    request.Timeout = 5000;     // 5 seconds

                    // send request and receive response
                    using (var response =
                        (HttpWebResponse)request.GetResponse())
                    {
                        HandleResponse(response);
                    }
                }
            }
            catch (Exception e)
            {
                Debug.Print(e.ToString());
            }
        }

        /// <summary>
        /// 
        /// </summary>
        /// <param name="baseUri"></param>
        /// <param name="sample"></param>
        /// <returns></returns>
        private static HttpWebRequest CreateRequest(string baseUri, string sample)
        {
            byte[] buffer = Encoding.UTF8.GetBytes(sample);

            var request = (HttpWebRequest)WebRequest.Create(baseUri);

            // request line
            request.Method = "PUT";

            // request headers
            request.ContentLength = buffer.Length;
            request.KeepAlive = false; //false si pb lors d'un transfert sur un réseau local (serveur Apache)!

            // request body
            using (Stream stream = request.GetRequestStream())
            {
                stream.Write(buffer, 0, buffer.Length);
            }

            return request;
        }

        /// <summary>
        /// 
        /// </summary>
        /// <param name="response"></param>
        private static void HandleResponse(HttpWebResponse response)
        {
            Debug.Print(response.Headers.ToString());
            Debug.Print(response.StatusCode.ToString());
        }


        /// <summary>
        /// 
        /// </summary>
        /// <param name="period"></param>
        public static void WaitUntilNextPeriod(int period)
        {
            long now = DateTime.Now.Ticks / TimeSpan.TicksPerMillisecond;
            var offset = (int)(now % period);
            int delay = period - offset;
            Debug.Print("sleep for " + delay + " ms\r\n");
            Thread.Sleep(delay);
        }
    }
}

