﻿using Gsiot.Server;
using Microsoft.SPOT;
using Microsoft.SPOT.Hardware;
using SecretLabs.NETMF.Hardware.NetduinoPlus;

namespace VoltageMonitor
{
    public class Program
    {
        public static void Main()
        {
            // ground and power for the potentiometer
           
            var voltageSensor = new AnalogSensor  // Initialiseur d'objets
            {
                InputPin = Cpu.AnalogChannel.ANALOG_1,
                MinValue = 0.0,
                MaxValue = 3.3
            };

            var webServer = new HttpServer
            {
                RequestRouting =
                {                                      
                // Renvoie la valeur de la tension 
                   {
                       "GET /voltage/actual", 
                        new MeasuredVariable 
                        {
                         FromSensor = voltageSensor.HandleGet
                        }.HandleRequest
                   },
                // Renvoie la valeur de la tension dans une page web  
                   { 
                       "GET /index.html", HandleRequestVoltage
                   },
                // Renvoie Hello    
                   {
                        "GET /hello", context => { context.SetResponse("Hello","text/plain"); }
                   },
                // Renvoie Erreur 404
                   {
                        "GET /*", context => { context.SetResponse("Erreur 404","text/plain"); }
                   },
                }
            };

            webServer.Run();
        }

        static void HandleRequestVoltage(RequestHandlerContext context)
        {
            var voltageSensor = new AnalogSensor  // Initialiseur d'objets
            {
                InputPin = Cpu.AnalogChannel.ANALOG_0,
                MinValue = 0.0,
                MaxValue = 3.3
            };
            
            string s =
                "<html>\r\n" +
                "\t<body>\r\n" +
                "\t\t <strong>Tension_I0 = </strong>" +
                   voltageSensor.HandleGet().ToString() + "V" + "\r\n" +
                "\t</body>\r\n" +
                "</html>";
            context.SetResponse(s, "text/html");
        }
    }
}
