﻿using System;
using Gsiot.Server;
using System.Threading;
using Microsoft.SPOT;
using Microsoft.SPOT.Hardware;
using SecretLabs.NETMF.Hardware.NetduinoPlus;

namespace paralleleVolet
{
    public class Program
    {
        public static void Main()
        {
            var buffer = new Buffer { };
            var volet = new volet { SourceBuffer = buffer };

            var webServer = new HttpServer
            {
                RequestRouting =
                {
                    {
                        "PUT /volet",
                        new ManipulatedVariable
                        {
                            FromHttpRequest =
                                CSharpRepresentation.TryDeserializeInt,
                            ToActuator = buffer.HandlePut
                        }.HandleRequest
                    },
                // ------------------------------------------------------------------------
                    {
                        "GET /index.html",
                        HandleBlinkTargetHtml
                    },
                // ------------------------------------------------------------------------
                    { 
                        "GET /*", Context => { Context.SetResponse("Entrer <IP>/index.html","text/plain");}
                    }
                }
            };

            var voletThread = new Thread(volet.Run);
            voletThread.Start();
            webServer.Run();        
        }

        static void HandleBlinkTargetHtml(RequestHandlerContext context)
        {
            string requestUri = context.BuildRequestUri("/volet");

            var script =
                @"<!DOCTYPE html>
              <html>
                <head>
                  <title>Volet M01</title> 
                  <script type=""text/javascript"">
                    var r;

                    try {
                      r = new XMLHttpRequest();
                    } catch (e) {
                      r = new ActiveXObject('Microsoft.XMLHTTP');
                    }

                    function put(content) {
                      if (content == '1'){ 
                            document.getElementById(""descend"").disabled = true;
                        }
                        else if (content == '2'){
                            document.getElementById(""monte"").disabled = true;
                        }
                        else
                        {
                            document.getElementById(""monte"").disabled = false;
                            document.getElementById(""descend"").disabled = false;
                        }                   
                      r.open('PUT', '" + requestUri + @"');
                      r.setRequestHeader(""Content-Type"", ""text/plain"");
                      r.send(content);
                    }
                  </script> 
                  <style type=""text/css"">
                    @media screen and (max-device-width:400px){
                    input {
                        width:100%;
                        height:200px;
                        font-size:80px;
                     }
                    }
                  </style>               
                </head>

                <body>
                  <p>
                    <input type=""button"" value=""Monte"" id =""monte"" onclick=""put('1')""/>
                    <input type=""button"" value=""Arret"" onclick=""put('0')""/>
                    <input type=""button"" value=""Descend"" id = ""descend"" onclick=""put('2')""/>
                  </p>
                </body>
              </html>";
            context.SetResponse(script, "text/html");
        }
    }
// ---------------------------------------------------------------------------------------------------------
    public class volet
    {
        public Buffer SourceBuffer { get; set; }

        public void Run()
        {
            var monte = new OutputPort(Pins.GPIO_PIN_D11, false);
            var descend = new OutputPort(Pins.GPIO_PIN_D10, false);

            var period = 500;

            while (true)
            {
                Thread.Sleep(period / 2);

                object setpoint = SourceBuffer.HandleGet();

                if (setpoint != null)
                {
                    if ((int)setpoint == 1)
                    {
                        monte.Write(true);
                    }
                    else if ((int)setpoint == 2)
                    {
                        descend.Write(true);
                    }
                    else
                    {
                        monte.Write(false);
                        descend.Write(false);
                    }
                }
            }
        }
    }
// ---------------------------------------------------------------------------------------------------------
}
